{% load i18n %}
{% load humanize %}

<!-- own srp requests tab -->
<div role="tabpanel" class="tab-pane fade" id="{{ tab_name }}">
    <div class="alert alert-info" role="alert">
        <div class="text-right srp-dashboard-user-isk-cost">
            {% translate "Your Total SRP Cost" %}: <span class="srp-dashboard-user-isk-cost-amount"></span>
        </div>
    </div>

    <div class="table-responsive">
        <table class="table table-striped table-aasrp table-pending-srp-requests table-vertical-middle" id="tab_aasrp_{{ tab_name }}" style="width: 100%;">
            <thead>
                <tr>
                    <th>{% translate "Request Time" %}</th>
                    <th>{% translate "Character" %}</th>
                    <th>{% translate "Fleet" %}</th>
                    <th>{% translate "SRP Code" %}</th>
                    <th>{% translate "Request Code" %}</th>
                    <th>{% translate "Ship" %}</th>
{#                    <th>{% translate "Killmail" %}</th>#}
                    <th>{% translate "ISK Lost" %}</th>
                    <th>{% translate "SRP Payout" %}</th>
                    <th><!-- {% translate "Status" %} --></th>
                </tr>
            </thead>
            <tbody></tbody>
        </table>
    </div>
</div>
